==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Totes les lletres</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuari</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferits</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activa</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Xinès</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>D&apos;un sol espai</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 és una família de lletres. Si procediu, se n&apos;eliminaran totes les lletres.</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 és una família de lletres. Si procediu, se n&apos;habilitaran totes les lletres.</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 és una família de lletres. Si procediu, se n&apos;inhabilitaran totes les lletres.</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Habilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Inhabilita</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Aplica-ho a totes les famílies de lletres seleccionades.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Fitxer trencat</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>N&apos;hi ha instal·lada la mateixa versió.</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Lletra del sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl + Maj. + /</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Pàgina amunt</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Pàgina avall</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl + Alt + F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl + F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl + O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl + =</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl + -</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl + 0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 lletra instal·lada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 lletres instal·lades</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Ha fallat instal·lar la lletra %1. No hi ha prou espai de disc.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Ha fallat instal·lar %1 lletres. No hi ha prou espai de disc.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">Fitxer trencat</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Aquesta lletra no estarà disponible a les aplicacions.</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Aquestes lletres no estaran disponibles a les aplicacions.</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Les altres %1 lletres del sistema no es poden eliminar.</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La lletra %1 en ús no es pot eliminar.</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Les altres %1 lletres del sistema i la lletra %2 no es poden eliminar.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Segur que voleu eliminar %1 lletra/es?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>S&apos;eliminen lletres. Espereu, si us plau...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificació de la lletra</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Cap font per instal·lar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Surt</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Continua</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informació bàsica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versió</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconeguda</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nom complet</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nom professional</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gestor de lletres</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>El Gestor de lletres ajuda els usuaris a instal·lar i gestionar tipus de lletres.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Es carreguen les lletres. Espereu, si us plau...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>La lletra s&apos;ha exportat a l&apos;escriptori.</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>&amp;1 lletres exportades a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Ha fallat exportar 1 lletra. No hi ha prou espai de disc.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Ha fallat exportar 1% lletres. No hi ha prou espai de disc.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Afegeix una lletra</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Inhabilita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Prefereix</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sense preferència</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra-ho al gestor de fitxers.</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivat</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Les lletres s&apos;han desactivat.</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 s&apos;usa; per tant, no es pot inhabilitar.</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>No podeu inhabilitar les lletres del sistema i les que s&apos;usen.</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>No podeu inhabilitar les lletres del sistema.</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instal·la la lletra</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Es verifica...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconeguda</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Fitxer trencat</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instal·lada</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>No instal·lada</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instal·la la lletra</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de la cerca.</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>No hi ha lletres.</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pàgina amunt</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pàgina avall</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Afegeix una lletra</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Prefereix</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sense preferència</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informació de la lletra</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Escriviu el text de previsualització.</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Totes les lletres</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuari</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferits</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activa</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Xinès</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>D&apos;un sol espai</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 és una família de lletres. Si procediu, se n&apos;eliminaran totes les lletres.</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 és una família de lletres. Si procediu, se n&apos;habilitaran totes les lletres.</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 és una família de lletres. Si procediu, se n&apos;inhabilitaran totes les lletres.</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Habilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Inhabilita</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Aplica-ho a totes les famílies de lletres seleccionades.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Fitxer trencat</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>N&apos;hi ha instal·lada la mateixa versió.</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Lletra del sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl + Maj. + /</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Pàgina amunt</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Pàgina avall</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl + Alt + F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl + F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl + O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl + =</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl + -</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl + 0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 lletra instal·lada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 lletres instal·lades</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Ha fallat instal·lar la lletra %1. No hi ha prou espai de disc.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Ha fallat instal·lar %1 lletres. No hi ha prou espai de disc.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Lletres</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Fitxer trencat</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Aquesta lletra no estarà disponible a les aplicacions.</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Aquestes lletres no estaran disponibles a les aplicacions.</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Les altres %1 lletres del sistema no es poden eliminar.</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La lletra %1 en ús no es pot eliminar.</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Les altres %1 lletres del sistema i la lletra %2 no es poden eliminar.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Segur que voleu eliminar %1 lletra/es?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>S&apos;eliminen lletres. Espereu, si us plau...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificació de la lletra</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Cap font per instal·lar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>No deixeu que els somnis siguin somnis.</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informació bàsica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versió</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconeguda</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nom complet</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nom professional</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Dret de còpia</translation>
    </message>
    <message>
        <source>License Description</source>
        <translation>Descripció de la llicència</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gestor de lletres</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>El Gestor de lletres ajuda els usuaris a instal·lar i gestionar tipus de lletres.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Es carreguen les lletres. Espereu, si us plau...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>La lletra s&apos;ha exportat a l&apos;escriptori.</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>&amp;1 lletres exportades a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Ha fallat exportar 1 lletra. No hi ha prou espai de disc.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Ha fallat exportar 1% lletres. No hi ha prou espai de disc.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Afegeix una lletra</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Inhabilita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Prefereix</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sense preferència</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra-ho al gestor de fitxers.</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivat</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Les lletres s&apos;han desactivat.</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 s&apos;usa; per tant, no es pot inhabilitar.</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>No podeu inhabilitar les lletres del sistema i les que s&apos;usen.</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>No podeu inhabilitar les lletres del sistema.</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instal·la la lletra</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Es verifica...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconeguda</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Fitxer trencat</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instal·lada</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>No instal·lada</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instal·la la lletra</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de la cerca.</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>No hi ha lletres.</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pàgina amunt</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pàgina avall</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Afegeix una lletra</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Prefereix</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sense preferència</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informació de la lletra</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Escriviu el text de previsualització.</translation>
    </message>
</context>
</TS>
